@@ -337,5 +337,8 @@
 	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_enable` tinyint(1) NOT NULL");
 	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_cmd` varchar(64) NOT NULL");
 	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_ok_r` varchar(64) character set utf8 NOT NULL");
+
+/*1.20.2*/
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `auto_reset_remain_enable` tinyint(1) NOT NULL");
 	echo "update done! <a href=''  target=_top>Return</a>";
 ?>
